summaryrefslogtreecommitdiff
path: root/soltools
diff options
context:
space:
mode:
Diffstat (limited to 'soltools')
-rw-r--r--soltools/mkdepend/main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/soltools/mkdepend/main.c b/soltools/mkdepend/main.c
index 58633c830115..b8b84b453476 100644
--- a/soltools/mkdepend/main.c
+++ b/soltools/mkdepend/main.c
@@ -473,7 +473,7 @@ struct filepointer *getfile(char *file)
struct stat st;
off_t size_backup;
ssize_t bytes_read;
- size_t malloc_size;
+ unsigned malloc_size;
content = (struct filepointer *)malloc(sizeof(struct filepointer));
if ((fd = open(file, O_RDONLY)) < 0) {
@@ -486,7 +486,7 @@ struct filepointer *getfile(char *file)
size_backup = st.st_size;
malloc_size = size_backup;
/* Since off_t usually is larger than size_t, need to test for
* truncation.
*/
if ( (off_t)malloc_size != size_backup )
@@ -486,7 +486,7 @@ struct filepointer *getfile(char *file)
size_backup = st.st_size;
malloc_size = size_backup;
- /* Since off_t usually is larger than size_t, need to test for
+ /* Since off_t usually is larger than unsigned, need to test for
* truncation.
*/